@@ -2,14 +2,7 @@ import json
 import argparse
 import pprint
 
-from parse_pdf.groupLines import ParsePdfClass
-from parse_pdf.groupDualDialogues import groupDualDialogues
-from parse_pdf.groupSections import groupSections
-from parse_pdf.SortLines import sortLines
-from parse_pdf.cleanPage import cleanPage
-from parse_pdf.getTopTrends import getTopTrends
-from parse_pdf.stitchSeperateWordsIntoLines import stitchSeperateWordsIntoLines
-from parse_pdf.processInitialPages import processInitialPages
+from screenplay_pdf_to_json.parse_pdf import ParsePdfClass, groupDualDialogues, groupSections, sortLines, cleanPage, getTopTrends, stitchSeperateWordsIntoLines, processInitialPages
 
 pp = pprint.PrettyPrinter(indent=4)
 
